@@ -4,21 +4,15 @@ use std::collections::VecDeque;
 
 /// The state required to visit [Changes] to be instantiated with `State::default()`.
 #[derive(Default, Clone)]
-pub struct State<PathId: Default + Clone> {
+pub struct State {
     buf1: Vec<u8>,
     buf2: Vec<u8>,
-    trees: VecDeque<TreeInfoPair<PathId>>,
+    trees: VecDeque<TreeInfoPair>,
 }
 
-type TreeInfoPair<PathId> = (Option<TreeInfo<PathId>>, Option<TreeInfo<PathId>>);
+type TreeInfoPair = (Option<ObjectId>, Option<ObjectId>);
 
-#[derive(Clone)]
-pub(crate) struct TreeInfo<PathId: Clone> {
-    pub tree_id: ObjectId,
-    pub parent_path_id: PathId,
-}
-
-impl<P: Clone + Default> State<P> {
+impl State {
     fn clear(&mut self) {
         self.trees.clear();
         self.buf1.clear();
